| methods.vcovmat | R Documentation |
Methods for objects of class "vcovmat".
## S3 method for class 'vcovmat'
print(x, digits=4, tol, zero=".", na="", ...)
## S3 method for class 'vcovmat'
x[i, j, ...]
x |
an object of class |
digits |
integer to specify the number of decimal places to which the printed results should be rounded (the default is 4). |
tol |
numeric value giving the tolerance for values that will be considered to be zeros. |
zero |
character string to represent zero values. |
na |
character string to represent missing values. |
i, j |
indices to select rows/columns. |
... |
other arguments. |
When printing a "vcovmat" object, values equal to zero are printed by default as a period. This makes it easier to see the structure of the variance-covariance matrix, which often has a block-diagonal structure. Values sufficiently close to zero are also treated as zero. This is controlled by the tol argument, which, if unspecified, is set by default to 10 * .Machine$double.eps.
To turn a matrix x of class "vcovmat" into a regular matrix, just use unclass(x).
The print method is based on the code from print.table with some minor tweaks.
Viechtbauer, W. (2010). Conducting meta-analyses in R with the metafor package. Journal of Statistical Software, 36(3), 1–48. https://doi.org/10.18637/jss.v036.i03
vcalc and rcalc for functions that create vcovmat objects.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.