"rma".radial(x, ...)
galbraith(x, ...)
## S3 method for class 'rma':
radial(x, center=FALSE, xlim, zlim, xlab, zlab,
atz, aty, steps=7, level=x$level, digits=2, back="lightgray",
transf=FALSE, targs, pch=19, arc.res=100, cex, \dots)"rma".FALSE).aty is used.NA to suppress shading of the region.transf=exp). Defaults to FALSE, which means that no transformation is used.transf.points for other options.rma.uni, rma.mh, rma.peto, rma.glmm, rma.mv### load BCG vaccine data
data(dat.bcg)
### meta-analysis of the log relative risks using a fixed-effects model
res <- rma(measure="RR", ai=tpos, bi=tneg, ci=cpos, di=cneg, data=dat.bcg, method="FE")
radial(res)
### line from (0,0) with slope equal to the log relative risk from the 4th study
abline(a=0, b=c(-1.44155119), lty="dotted")
### meta-analysis of the log relative risks using a random-effects model
res <- rma(measure="RR", ai=tpos, bi=tneg, ci=cpos, di=cneg, data=dat.bcg)
radial(res)Run the code above in your browser using DataLab