| cmicalc | R Documentation |
Function to calculate the bias correction factor for standardized mean differences and related measures. \loadmathjax
cmicalc(mi, method="exact")
mi |
numeric vector. |
method |
character string to specify if the exact ( |
Standardized mean differences (Cohen's d values) have a slight positive bias (i.e., they tend to be too large on average). Hedges (1981) derived the bias correction factor to make make standardized mean differences unbiased (yielding what is commonly referred to as Hedges' g values).
The function computes the bias correction factor, using \mjseqnm_i as input. For standardized mean differences, this is equal to \mjseqnm_i = n_1i + n_2i - 2, where \mjseqnn_1i and \mjseqnn_2i are the number of subjects in the two groups. The same bias correction factor can be used for various other related measures, such as standardized mean changes, except that \mjseqnm_i may need to be calculated differently.
By default (i.e., when method="exact"), the method uses the exact formula to calculate the bias correction factor (equation 6e in Hedges, 1981), that is, \mjsdeqnc(m_i) = \frac\Gamma(\fracm_i2)\sqrt\fracm_i2\Gamma(\fracm_i-12). When method="approx", the (very accurate) approximation \mjsdeqnc(m_i) = 1 - \frac34m_i -1 is used instead (first equation on page 114 in Hedges, 1981).
A numeric vector of length equal to the length of mi.
The notation \mjseqnc(m_i) is based on that used in Hedges (1981). Later publications and references often denote the bias correction factor \mjseqnJ or \mjseqnJ(m_i).
Wolfgang Viechtbauer (wvb@metafor-project.org, https://www.metafor-project.org).
Hedges, L. V. (1981). Distribution theory for Glass's estimator of effect size and related estimators. Journal of Educational Statistics, 6(2), 107–128. https://doi.org/10.3102/10769986006002107
escalc for a function that makes use of this bias correction.
### copy dataset to dat
dat <- dat.furukawa2003
### calculate the bias correction factor for each study
dat$mi <- dat$Ne + dat$Nc - 2
dat$cmi <- cmicalc(dat$mi)
dat
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.