Blah.

hettest(x, vi, sei, subset, data, method="REML",
        test="score", boot=TRUE, progbar=TRUE, digits, ...)

Arguments

x

a vector with the observed effect sizes or outcomes or an object of class "rma".

vi

vector with the corresponding sampling variances (ignored if x is an object of class "rma").

sei

vector with the corresponding standard errors (note: only one of the two, vi or sei, needs to be specified).

subset

optional (logical or numeric) vector to specify the subset of studies that should be used for the calculation (ignored if x is an object of class "rma").

data

optional data frame containing the variables given to the arguments above.

method

character string.

test

optional character string. See ‘Details’.

boot

logical.

progbar

logical.

digits

optional integer to specify the number of decimal places to which the printed results should be rounded.

...

other arguments.

Details

Blah.

Value

An object of class "hettest". The object is a list containing the following components:

x2

blah.

df

blah.

pval

the p-value.

...

some additional elements/values.