hettest.RdBlah.
hettest(x, vi, sei, subset, data, method="REML",
test="score", boot=TRUE, progbar=TRUE, digits, ...)a vector with the observed effect sizes or outcomes or an object of class "rma".
vector with the corresponding sampling variances (ignored if x is an object of class "rma").
vector with the corresponding standard errors (note: only one of the two, vi or sei, needs to be specified).
optional (logical or numeric) vector to specify the subset of studies that should be used for the calculation (ignored if x is an object of class "rma").
optional data frame containing the variables given to the arguments above.
character string.
optional character string. See ‘Details’.
logical.
logical.
optional integer to specify the number of decimal places to which the printed results should be rounded.
other arguments.
Blah.
An object of class "hettest". The object is a list containing the following components:
blah.
blah.
the p-value.
some additional elements/values.