Print method for objects of class "permutest.rma.uni".
# S3 method for permutest.rma.uni
print(x, digits, signif.stars=getOption("show.signif.stars"),
signif.legend=signif.stars, …)an object of class "permutest.rma.uni".
integer specifying the number of decimal places to which the printed results should be rounded (if unspecified, the default is to take the value from the object).
logical indicating whether p-values should be encoded visually with ‘significance stars’. Defaults to the show.signif.stars slot of options.
logical indicating whether the legend for the ‘significance stars’ should be printed. Defaults to the value for signif.stars.
other arguments.
The function does not return an object.
The output includes:
the results of the omnibus test of the coefficients in the model. Suppressed if the model includes only one coefficient (e.g., only an intercept, like in the fixed- and random-effects model). The p-value based on the permutation test is indicated by p-val*.
a table with the estimated coefficients, corresponding standard errors, test statistics, p-values, and confidence interval bounds. The p-values based on the permutation test are indicated by pval*. When permutation-based CIs have been obtained, then the CI bounds are indicated with ci.lb* and ci.ub*.
Viechtbauer, W. (2010). Conducting meta-analyses in R with the metafor package. Journal of Statistical Software, 36(3), 1--48. http://www.jstatsoft.org/v36/i03/.