The observed residuals (obtained with residuals) are simply equal to the observed - fitted values. Dividing the observed residuals by their corresponding standard errors yields (internally) standardized residuals. These can be obtained with rstandard.
The rstudent function calculates externally standardized residuals (studentized deleted residuals). The externally standardized residual for the $i$th case is obtained by deleting the $i$th case from the dataset, fitting the model based on the remaining cases, calculating the predicted value for the $i$th case based on the fitted model, taking the difference between the observed and the predicted value for the $i$th case (the deleted residual), and then standardizing the deleted residual. The standard error of the deleted residual is equal to the square root of the sampling variance of the $i$th case plus the variance of the predicted value plus the amount of (residual) heterogeneity from the fitted model (for fixed-effects models, this last part is always equal to zero).
If a particular study fits the model, its standardized residual follows (asymptotically) a standard normal distribution. A large standardized residual for a study therefore may suggest that the study does not fit the assumed model (i.e., it may be an outlier).
See also influence.rma.uni for other leave-one-out diagnostics that are useful for detecting influential cases in models fitted with the rma.uni function.